# -*- coding: utf_8 -*-
from django.contrib import admin
#from django.contrib.auth.admin import UserAdmin
#from django.contrib.auth.models import User

from .models import *
from .forms import MyParticipantesForm, MyPessoaForm, MyTimeForm, MyExperienciaForm, MyPeriodoPessoaForm



class TextoAdmin(admin.ModelAdmin):
    pass


class RegiaoAdmin(admin.ModelAdmin):
    pass


class TagAdmin(admin.ModelAdmin):
    pass


class TemaAdmin(admin.ModelAdmin):
    filter_horizontal = ['tags', 'regioes']


class ParticipantesInline(admin.TabularInline):
    form = MyParticipantesForm
    model = Participantes
    filter_horizontal = ['pessoas']
    max_num = 1

class AtividadeAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {
            'fields': ('apelido', 'tema')
        }),
        ('Modo de uso', {
            'fields': ('tamanho_time',)
        }),
        ('Uso Compartilhado', {
            'fields': ('tempo_participante', 'tags_sequenciais')
        }),
        ('Configurações Gerais', {
            'fields': ('tempo_total', 'tags_por_foto', 'tags_selecionaveis', 'tags_localizaveis', 'tempo_som', 'criterio_ordenacao', 'modo_verboso', 'inclusao_usuario')
        }),
        ('Exportação', {
            'fields': ('url_experiencia', 'url_dinamica')
        }),
    )

    inlines = [
        ParticipantesInline,
    ]

    list_display = ('apelido', 'tema', 'criterio_ordenacao')
    list_filter = ('tema__texto__titulo', 'criterio_ordenacao')
    search_fields = ['apelido', 'tema__texto__conteudo']


class PessoaAdmin(admin.ModelAdmin):
    form = MyPessoaForm
    filter_horizontal = ['regioes', 'tags']

    #list_display = ('user__username',)


class ParticipantesAdmin(admin.ModelAdmin):
    form = MyParticipantesForm
    filter_horizontal = ['pessoas']


class FotoInline(admin.StackedInline):
    model = Foto
    filter_horizontal = ['tags']
    extra = 1

class TimeInline(admin.TabularInline):
    model = Time
    filter_horizontal = ['pessoas']
    extra = 1

class ExperienciaAdmin(admin.ModelAdmin):
    #actions_on_top = True
    #actions_on_bottom = True
    #date_hierarchy = 'periodo_inicio' # Requires pytz
    form = MyExperienciaForm

    list_display = ('atividade', 'periodo_inicio', 'periodo_fim', 'status')
    list_filter = ('periodo_inicio', 'periodo_fim', 'status')
    ordering = ('periodo_inicio',)
    search_fields = ['atividade__apelido', 'atividade__tema__texto__titulo',
                     'atividade__tema__texto__conteudo']

    inlines = [
        FotoInline,
        TimeInline,
    ]


class PeriodoPessoaInline(admin.TabularInline):
    model = PeriodoPessoa

class TimeAdmin(admin.ModelAdmin):
    form = MyTimeForm
    filter_horizontal = ['pessoas']

    inlines = [
        PeriodoPessoaInline,
    ]


class PeriodoPessoaAdmin(admin.ModelAdmin):
    form = MyPeriodoPessoaForm


class FotoAdmin(admin.ModelAdmin):
    filter_horizontal = ['tags']

    # https://www.quora.com/How-to-save-django-model-form-with-many-to-many-field
    # http://stackoverflow.com/questions/33527533/django-override-default-save-add-manytomany
    # http://timonweb.com/posts/many-to-many-field-save-method-and-the-django-admin/
    # https://docs.djangoproject.com/en/1.9/ref/contrib/admin/#django.contrib.admin.ModelAdmin.save_related
#    def save_related(self, request, form, formsets, change):
#	super(FotoAdmin, self).save_related(request, form, formsets, change)
#	for tag in form.instance.tags.values_list():
#	    print tag
#	#form.save_m2m()


admin.site.register(Texto, TextoAdmin)
admin.site.register(Regiao, RegiaoAdmin)
admin.site.register(Tag, TagAdmin)
admin.site.register(Tema, TemaAdmin)
admin.site.register(Atividade, AtividadeAdmin)
admin.site.register(Pessoa, PessoaAdmin)
admin.site.register(Participantes, ParticipantesAdmin)
admin.site.register(Experiencia, ExperienciaAdmin)
admin.site.register(Time, TimeAdmin)
admin.site.register(PeriodoPessoa, PeriodoPessoaAdmin)
admin.site.register(Foto, FotoAdmin)
