# -*- coding: utf_8 -*-
"""revelar_ng URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.8/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Add an import:  from blog import urls as blog_urls
    2. Add a URL to urlpatterns:  url(r'^blog/', include(blog_urls))
"""
from django.conf.urls import include, url
from django.contrib import admin
from django.conf import settings
from django.conf.urls.static import static
from rest_framework import routers
from revelar import views


router = routers.DefaultRouter()
router.register(r'textos', views.TextoViewSet)
router.register(r'regioes', views.RegiaoViewSet)
router.register(r'tags', views.TagViewSet)
router.register(r'temas', views.TemaViewSet)
router.register(r'atividades', views.AtividadeViewSet)
router.register(r'users', views.UserViewSet)
router.register(r'pessoas', views.PessoaViewSet)
router.register(r'participantes', views.ParticipantesViewSet)
router.register(r'experiencias', views.ExperienciaViewSet)
router.register(r'times', views.TimeViewSet)
router.register(r'periodo-pessoa', views.PeriodoPessoaViewSet)
router.register(r'fotos', views.FotoViewSet)

# https://docs.djangoproject.com/en/1.10/ref/contrib/admin/#django.contrib.admin.AdminSite.site_header
# http://stackoverflow.com/a/24983231
admin.site.site_header = 'Administração do Revelar'


urlpatterns = [
    url(r'^', include('revelar.urls')),
    url(r'^admin/', include(admin.site.urls)),

    # Django Rest Framework
    url(r'^api/experiencias-em-andamento/(?P<atividade_id>\d+)/$', views.experiencia_em_andamento),
    url(r'^api/experiencia-encerrada/(?P<experiencia_id>\d+)/$', views.experiencia_encerrada, name='experiencia_encerrada'),
    url(r'^api/', include(router.urls)),
    url(r'^api-auth/', include('rest_framework.urls', namespace='rest_framework')),
    url(r'^ping/', views.ping),
    url(r'^signin/(?P<apelido>[\w ]+)/$', views.sign_in),
    url(r'^signup/', views.sign_up),
    url(r'^usuarios-de-time/', views.usuarios_de_time),

    # Fechamento
    url(r'^fechamento/', include('fechamento.urls', namespace='fechamento')),
] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
